@@ -66,18 +66,21 @@
 #' # `overwrite = TRUE` moves an existing file to trash, then proceeds
 #' drive_create("VisiCalc", path = b4xl, overwrite = TRUE)
 #'
-#' # clean up
+#' # Clean up
 #' drive_rm(wordstar, b4xl, execuvision)
-drive_create <- function(name,
-                         path = NULL,
-                         type = NULL,
-                         ...,
-                         overwrite = NA,
-                         verbose = deprecated()) {
+drive_create <- function(
+  name,
+  path = NULL,
+  type = NULL,
+  ...,
+  overwrite = NA,
+  verbose = deprecated()
+) {
   warn_for_verbose(verbose)
 
   # in the special case of creating a shortcut, `name` is not required
   if (!identical(drive_mime_type(type), drive_mime_type("shortcut"))) {
+    check_required(name)
     stopifnot(is_string(name))
   }
   # the order and role of `path` and `name` is naturally inverted here,
@@ -117,7 +120,12 @@ drive_create <- function(name,
     "Created Drive file:",
     bulletize(gargle_map_cli(out)),
     "With MIME type:",
-    bulletize(gargle_map_cli(purrr::pluck(out, 'drive_resource', 1, 'mimeType')))
+    bulletize(gargle_map_cli(purrr::pluck(
+      out,
+      "drive_resource",
+      1,
+      "mimeType"
+    )))
   ))
   invisible(out)
 }
