@@ -1,5 +1,11 @@
 # path utilities that CAN call the Drive API ----
-root_folder <- function() drive_get(id = "root")
+root_folder <- function() {
+  # inlining env_cache() logic, so I don't need bleeding edge rlang
+  if (!env_has(.googledrive, "root_folder")) {
+    env_poke(.googledrive, "root_folder", drive_get(id = "root"))
+  }
+  env_get(.googledrive, "root_folder")
+}
 root_id <- function() root_folder()$id
 
 rationalize_path_name <- function(path = NULL, name = NULL) {
@@ -18,22 +24,28 @@ rationalize_path_name <- function(path = NULL, name = NULL) {
 }
 
 confirm_clear_path <- function(path, name) {
-  if (is.null(name) &&
+  if (
+    is.null(name) &&
       !has_slash(path) &&
-      drive_path_exists(append_slash(path))) {
-    stop_glue(
-      "Unclear if `path` specifies parent folder or full path\n",
-      "to the new file, including its name. ",
-      "See ?as_dribble() for details."
-    )
+      drive_path_exists(append_slash(path))
+  ) {
+    drive_abort(c(
+      "Unclear if {.arg path} specifies parent folder or full path \\
+       to the new file, including its name.",
+      "See {.fun ?as_dribble} for advice on how to make this clear."
+    ))
   }
 }
 
-drive_path_exists <- function(path, verbose = TRUE) {
+drive_path_exists <- function(path) {
   stopifnot(is_path(path))
-  if (length(path) == 0) return(logical(0))
+  if (length(path) == 0) {
+    return(logical(0))
+  }
   stopifnot(length(path) == 1)
-  some_files(drive_get(path = path))
+  with_drive_quiet(
+    some_files(drive_get(path = path))
+  )
 }
 
 # `parent` is NULL or the file ID of a folder
@@ -52,22 +64,23 @@ check_for_overwrite <- function(parent = NULL, name, overwrite) {
 
   # Unhappy Paths: multiple collisions and/or not allowed to trash anything
   hits <- drive_reveal(hits, "path")
-  msg <- glue("  * {hits$path}: {hits$id}")
 
   if (overwrite) {
-    msg <- c(
+    drive_abort(c(
       "Multiple items already exist at the target filepath.",
-      "Although `overwrite = TRUE`, it's not clear which item to overwrite.",
-      "Use `overwrite = NA` to suppress this check. Aborting.",
-      msg
-    )
+      bulletize(gargle_map_cli(hits, bullet = "x")),
+      "Although {.code overwrite = TRUE}, it's not clear which item \\
+       to overwrite.",
+      "Use {.code overwrite = NA} to suppress this check. Exiting."
+    ))
   } else {
-    msg <- c(
-      "One or more items already exist at the target filepath and `overwrite = FALSE`:",
-      msg
-    )
+    drive_abort(c(
+      # \u00a0 is a nonbreaking space
+      "{nrow(hits)} item{?s} already exist{?s/} at the target filepath \\
+       and {.code overwrite\u00a0=\u00a0FALSE}:",
+      bulletize(gargle_map_cli(hits, bullet = "x"))
+    ))
   }
-  stop_glue(glue_collapse(msg, sep = "\n"))
 }
 
 overwrite_hits <- function(parent = NULL, name, overwrite) {
@@ -82,27 +95,33 @@ overwrite_hits <- function(parent = NULL, name, overwrite) {
     glue("name = '{name}'"),
     "trashed = FALSE"
   )
-  drive_find(q = q)
+  # suppress drive_find() status updates
+  local_drive_quiet()
+  drive_find(q = q, corpus = "allDrives")
 }
 
 # path utilities that are "mechanical", i.e. they NEVER call the Drive API ----
+dribble_with_path <- function() {
+  put_column(dribble(), nm = "path", val = character(), .after = "name")
+}
 
-is_path <- function(x) is.character(x) && !inherits(x, "drive_id")
+is_path <- function(x) is.character(x) && !is_drive_id(x)
 
 is_string <- function(x) length(x) == 1L && is_path(x)
 
-is_rootpath <- function(path) {
-  is_string(path) && grepl("^~$|^/$|^~/$", path)
-}
-
-is_rooted <- function(path) grepl("^~", path)
-
-## turn '~' into `~/`
-## turn leading `/` into leading `~/`
+# turn '~' into `~/`
 rootize_path <- function(path) {
-  if (length(path) == 0) return(path)
+  if (length(path) == 0) {
+    return(path)
+  }
   stopifnot(is.character(path))
-  sub("^~$|^/", "~/", path)
+  leading_slash <- startsWith(path, "/")
+  if (any(leading_slash)) {
+    drive_abort(
+      "{.pkg googledrive} does not allow paths to start with {.code /}"
+    )
+  }
+  sub("^~$", "~/", path)
 }
 
 ## does path have a trailing slash?
@@ -112,7 +131,9 @@ has_slash <- function(path) {
 
 ## "a/b/" and "a/b" both return "a/b/"
 append_slash <- function(path) {
-  if (length(path) < 1) return(path)
+  if (length(path) < 1) {
+    return(path)
+  }
   ifelse(has_slash(path) | path == "", path, paste0(path, "/"))
 }
 
@@ -121,22 +142,13 @@ strip_slash <- function(path) {
   gsub("/$", "", path)
 }
 
-split_path <- function(path = "") {
-  path <- path %||% ""
-  unlist(strsplit(rootize_path(path), "/"))
-}
-
-unsplit_path <- function(...) {
-  gsub("^/*", "", file.path(...))
-}
-
-## partitions path into
-##   * name = substring after the last `/`
-##   * parent = substring up to the last `/`, processed with rootize_path()
-## if there is no `/`, put the input into `name`
-## use maybe_name if you have external info re: how to interpret the path
-## maybe_name = TRUE --> path could end in a name
-## maybe_name = FALSE --> path is known to be a directory
+# partitions path into
+#   * name = substring after the last `/`
+#   * parent = substring up to the last `/`
+# if there is no `/`, put the input into `name`
+# use maybe_name if you have external info re: how to interpret the path
+# maybe_name = TRUE --> path could end in a name
+# maybe_name = FALSE --> path is known to be a directory
 partition_path <- function(path, maybe_name = FALSE) {
   out <- list(parent = NULL, name = NULL)
   if (length(path) < 1) {
@@ -173,6 +185,9 @@ file_ext_safe <- function(x) {
 
 ## add an extension if it is not already present
 apply_extension <- function(path, ext) {
+  if (is.na(ext) || ext == "") {
+    return(path)
+  }
   ext_orig <- file_ext_safe(path)
   if (!identical(ext, ext_orig)) {
     path <- paste(path, ext, sep = ".")
