@@ -1,5 +1,3 @@
-context("MIME type helper")
-
 # ---- tests ----
 test_that("drive_mime_type() returns NULL if no input", {
   expect_null(drive_mime_type())
@@ -24,13 +22,13 @@ test_that("drive_mime_type() returns MIME type for Drive native type", {
 
 test_that("drive_mime_type() returns MIME type for file extension", {
   expect_identical(
-    drive_mime_type(c("pdf", "jpeg")),
-    c("application/pdf", "image/jpeg")
+    drive_mime_type(c("pdf", "jpeg", "md")),
+    c("application/pdf", "image/jpeg", "text/markdown")
   )
 })
 
 test_that("drive_mime_type() returns MIME type for MIME type", {
-  input <- c("application/vnd.ms-excel", "text/html")
+  input <- c("application/vnd.ms-excel", "text/html", "text/x-markdown")
   expect_identical(drive_mime_type(input), input)
 })
 
@@ -43,12 +41,12 @@ test_that("drive_mime_type() returns MIME type for mixed input", {
 })
 
 test_that("drive_mime_type() errors for invalid input", {
-  expect_error(drive_mime_type(1), "'type' must be character")
-  expect_error(drive_mime_type(dribble()), "'type' must be character")
+  expect_snapshot(drive_mime_type(1), error = TRUE)
+  expect_snapshot(drive_mime_type(dribble()), error = TRUE)
 })
 
 test_that("drive_mime_type() errors for single unrecognized input", {
-  expect_error(drive_mime_type("nonsense"), "Unrecognized 'type'")
+  expect_snapshot(drive_mime_type("nonsense"), error = TRUE)
 })
 
 test_that("drive_extension() returns NULL if no input", {
@@ -57,8 +55,8 @@ test_that("drive_extension() returns NULL if no input", {
 
 test_that("drive_extension() returns file extension for MIME type", {
   expect_identical(
-    drive_extension(c("application/pdf", "image/jpeg")),
-    c("pdf", "jpeg")
+    drive_extension(c("application/pdf", "image/jpeg", "text/x-markdown")),
+    c("pdf", "jpeg", "md")
   )
 })
 
@@ -76,10 +74,10 @@ test_that("drive_extension() returns file extension for mixed input", {
 })
 
 test_that("drive_extension() errors for invalid input", {
-  expect_error(drive_extension(1), "is\\.character\\(type\\) is not TRUE")
-  expect_error(drive_extension(dribble()), "is\\.character\\(type\\) is not TRUE")
+  expect_snapshot(drive_extension(1), error = TRUE)
+  expect_snapshot(drive_extension(dribble()), error = TRUE)
 })
 
 test_that("drive_extension() errors for single unrecognized input", {
-  expect_error(drive_extension("nonsense"), "Unrecognized 'type'")
+  expect_snapshot(drive_extension("nonsense"), error = TRUE)
 })
